@@ -1,4 +1,4 @@
-path <- file.path("test", "testthat")
+path <- file.path("tests", "testthat")
 test_files <- dir(path, pattern = "test_")
 
 sapply(file.path(path, test_files), source)
